# Email field

The email field mirrors the [basic field](./basic_field.md) for functionality. The only difference is
that it renders an email input and if browser validation is enabled on the form then the browser
will validate those email addresses appropriately.

See the [basic field](./basic_field.md) documentation for configuration options.
